============
About mosaik
============

The latest version of mosaik is 2.3.0 and it is licensed under `LGPL`__.

__ http://www.gnu.org/licenses/lgpl-3.0.en.html

Contents:

.. toctree::
   :maxdepth: 1

   acknowledgements
   history
